package p023h0;

import android.os.Build;
import android.util.Log;
import android.view.View;
import android.view.ViewParent;

/* renamed from: h0.i4 */
/* loaded from: classes.dex */
public final class C0860i4 {

    /* renamed from: h0.i4$a */
    /* loaded from: classes.dex */
    public static class C0861a {
        /* renamed from: a */
        public static boolean m2670a(ViewParent viewParent, View view, float f, float f2, boolean z) {
            boolean onNestedFling;
            onNestedFling = viewParent.onNestedFling(view, f, f2, z);
            return onNestedFling;
        }

        /* renamed from: b */
        public static boolean m2669b(ViewParent viewParent, View view, float f, float f2) {
            boolean onNestedPreFling;
            onNestedPreFling = viewParent.onNestedPreFling(view, f, f2);
            return onNestedPreFling;
        }

        /* renamed from: c */
        public static void m2668c(ViewParent viewParent, View view, int i, int i2, int[] iArr) {
            viewParent.onNestedPreScroll(view, i, i2, iArr);
        }

        /* renamed from: d */
        public static void m2667d(ViewParent viewParent, View view, int i, int i2, int i3, int i4) {
            viewParent.onNestedScroll(view, i, i2, i3, i4);
        }

        /* renamed from: e */
        public static void m2666e(ViewParent viewParent, View view, View view2, int i) {
            viewParent.onNestedScrollAccepted(view, view2, i);
        }

        /* renamed from: f */
        public static boolean m2665f(ViewParent viewParent, View view, View view2, int i) {
            boolean onStartNestedScroll;
            onStartNestedScroll = viewParent.onStartNestedScroll(view, view2, i);
            return onStartNestedScroll;
        }

        /* renamed from: g */
        public static void m2664g(ViewParent viewParent, View view) {
            viewParent.onStopNestedScroll(view);
        }
    }

    /* renamed from: a */
    public static boolean m2677a(ViewParent viewParent, View view, float f, float f2, boolean z) {
        if (Build.VERSION.SDK_INT < 21) {
            if (viewParent instanceof InterfaceC0989y0) {
                return ((InterfaceC0989y0) viewParent).onNestedFling(view, f, f2, z);
            }
            return false;
        }
        try {
            return C0861a.m2670a(viewParent, view, f, f2, z);
        } catch (AbstractMethodError e) {
            Log.e("ViewParentCompat", "ViewParent " + viewParent + " does not implement interface method onNestedFling", e);
            return false;
        }
    }

    /* renamed from: b */
    public static boolean m2676b(ViewParent viewParent, View view, float f, float f2) {
        if (Build.VERSION.SDK_INT < 21) {
            if (viewParent instanceof InterfaceC0989y0) {
                return ((InterfaceC0989y0) viewParent).onNestedPreFling(view, f, f2);
            }
            return false;
        }
        try {
            return C0861a.m2669b(viewParent, view, f, f2);
        } catch (AbstractMethodError e) {
            Log.e("ViewParentCompat", "ViewParent " + viewParent + " does not implement interface method onNestedPreFling", e);
            return false;
        }
    }

    /* renamed from: c */
    public static void m2675c(ViewParent viewParent, View view, int i, int i2, int[] iArr, int i3) {
        if (viewParent instanceof InterfaceC0974w0) {
            ((InterfaceC0974w0) viewParent).mo727j(view, i, i2, iArr, i3);
        } else if (i3 == 0) {
            if (Build.VERSION.SDK_INT < 21) {
                if (viewParent instanceof InterfaceC0989y0) {
                    ((InterfaceC0989y0) viewParent).onNestedPreScroll(view, i, i2, iArr);
                    return;
                }
                return;
            }
            try {
                C0861a.m2668c(viewParent, view, i, i2, iArr);
            } catch (AbstractMethodError e) {
                Log.e("ViewParentCompat", "ViewParent " + viewParent + " does not implement interface method onNestedPreScroll", e);
            }
        }
    }

    /* renamed from: d */
    public static void m2674d(ViewParent viewParent, View view, int i, int i2, int i3, int i4, int i5, int[] iArr) {
        if (viewParent instanceof InterfaceC0982x0) {
            ((InterfaceC0982x0) viewParent).mo726m(view, i, i2, i3, i4, i5, iArr);
            return;
        }
        iArr[0] = iArr[0] + i3;
        iArr[1] = iArr[1] + i4;
        if (viewParent instanceof InterfaceC0974w0) {
            ((InterfaceC0974w0) viewParent).mo725n(view, i, i2, i3, i4, i5);
        } else if (i5 == 0) {
            if (Build.VERSION.SDK_INT < 21) {
                if (viewParent instanceof InterfaceC0989y0) {
                    ((InterfaceC0989y0) viewParent).onNestedScroll(view, i, i2, i3, i4);
                    return;
                }
                return;
            }
            try {
                C0861a.m2667d(viewParent, view, i, i2, i3, i4);
            } catch (AbstractMethodError e) {
                Log.e("ViewParentCompat", "ViewParent " + viewParent + " does not implement interface method onNestedScroll", e);
            }
        }
    }

    /* renamed from: e */
    public static void m2673e(ViewParent viewParent, View view, View view2, int i, int i2) {
        if (viewParent instanceof InterfaceC0974w0) {
            ((InterfaceC0974w0) viewParent).mo729d(view, view2, i, i2);
        } else if (i2 == 0) {
            if (Build.VERSION.SDK_INT < 21) {
                if (viewParent instanceof InterfaceC0989y0) {
                    ((InterfaceC0989y0) viewParent).onNestedScrollAccepted(view, view2, i);
                    return;
                }
                return;
            }
            try {
                C0861a.m2666e(viewParent, view, view2, i);
            } catch (AbstractMethodError e) {
                Log.e("ViewParentCompat", "ViewParent " + viewParent + " does not implement interface method onNestedScrollAccepted", e);
            }
        }
    }

    /* renamed from: f */
    public static boolean m2672f(ViewParent viewParent, View view, View view2, int i, int i2) {
        if (viewParent instanceof InterfaceC0974w0) {
            return ((InterfaceC0974w0) viewParent).mo724o(view, view2, i, i2);
        }
        if (i2 == 0) {
            if (Build.VERSION.SDK_INT < 21) {
                if (viewParent instanceof InterfaceC0989y0) {
                    return ((InterfaceC0989y0) viewParent).onStartNestedScroll(view, view2, i);
                }
                return false;
            }
            try {
                return C0861a.m2665f(viewParent, view, view2, i);
            } catch (AbstractMethodError e) {
                Log.e("ViewParentCompat", "ViewParent " + viewParent + " does not implement interface method onStartNestedScroll", e);
                return false;
            }
        }
        return false;
    }

    /* renamed from: g */
    public static void m2671g(ViewParent viewParent, View view, int i) {
        if (viewParent instanceof InterfaceC0974w0) {
            ((InterfaceC0974w0) viewParent).mo728i(view, i);
        } else if (i == 0) {
            if (Build.VERSION.SDK_INT < 21) {
                if (viewParent instanceof InterfaceC0989y0) {
                    ((InterfaceC0989y0) viewParent).onStopNestedScroll(view);
                    return;
                }
                return;
            }
            try {
                C0861a.m2664g(viewParent, view);
            } catch (AbstractMethodError e) {
                Log.e("ViewParentCompat", "ViewParent " + viewParent + " does not implement interface method onStopNestedScroll", e);
            }
        }
    }
}